summaryrefslogtreecommitdiffstats
path: root/examples/pytde-sampler
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-22 20:03:49 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-22 20:03:49 -0600
commit387a27b62f25387e42a850739ced151d64a2e760 (patch)
treebbba39b506feb102175f10aa296b201a5a4557f5 /examples/pytde-sampler
parent3d1fa8562bf693237a1a76918b4487cca3e2e356 (diff)
downloadpytde-387a27b62f25387e42a850739ced151d64a2e760.tar.gz
pytde-387a27b62f25387e42a850739ced151d64a2e760.zip
Rename KInstance and KAboutData to avoid conflicts with KDE4
Diffstat (limited to 'examples/pytde-sampler')
-rw-r--r--examples/pytde-sampler/about.py10
-rw-r--r--examples/pytde-sampler/qt_widgets/CONTRIB4
-rwxr-xr-xexamples/pytde-sampler/sampler.py2
3 files changed, 8 insertions, 8 deletions
diff --git a/examples/pytde-sampler/qt_widgets/CONTRIB b/examples/pytde-sampler/qt_widgets/CONTRIB
index 3c741aa..4a37f4f 100644
--- a/examples/pytde-sampler/qt_widgets/CONTRIB
+++ b/examples/pytde-sampler/qt_widgets/CONTRIB
@@ -11,7 +11,7 @@ tdecore,BarIconSet,,,
tdecore,DesktopIcon,,,
tdecore,DesktopIconSet,,,
tdecore,IconSize,,,
-tdecore,KAboutData,,,
+tdecore,TDEAboutData,,,
tdecore,KAboutPerson,,,
tdecore,KAboutTranslator,,,
tdecore,KAccel,,,
@@ -57,7 +57,7 @@ tdecore,KIcon,,,
tdecore,KIconEffect,,,
tdecore,KIconLoader,,,
tdecore,KIconTheme,,,
-tdecore,KInstance,,,
+tdecore,TDEInstance,,,
tdecore,KKey,,,
tdecore,KKeyNative,,,
tdecore,KKeySequence,,,
diff --git a/examples/pytde-sampler/sampler.py b/examples/pytde-sampler/sampler.py
index 4e7eb43..f8048f8 100755
--- a/examples/pytde-sampler/sampler.py
+++ b/examples/pytde-sampler/sampler.py
@@ -14,7 +14,7 @@ from qt import SIGNAL, SLOT, PYSIGNAL, TQt
from qt import TQVBoxLayout, TQLabel, TQPixmap, TQSplitter, TQFrame, TQDialog
from qt import TQSizePolicy, TQHBoxLayout, TQSpacerItem, TQPushButton
-from tdecore import i18n, KAboutData, TDEApplication, TDECmdLineArgs, KGlobal
+from tdecore import i18n, TDEAboutData, TDEApplication, TDECmdLineArgs, KGlobal
from tdecore import KGlobalSettings, KWin, KWinModule, KURL, KIcon
from tdeui import KComboBox, KListView, KListViewItem, KTabWidget, KTextEdit
diff --git a/examples/pytde-sampler/about.py b/examples/pytde-sampler/about.py
index 108194b..f675b1c 100644
--- a/examples/pytde-sampler/about.py
+++ b/examples/pytde-sampler/about.py
@@ -1,11 +1,11 @@
#!/usr/bin/env python
""" About the PyKDE Sampler
-Defines the 'about' function to create a KAboutData instance for the
+Defines the 'about' function to create a TDEAboutData instance for the
sampler application.
"""
from os.path import dirname, join
-from tdecore import KAboutData
+from tdecore import TDEAboutData
appName = 'pytdesampler'
@@ -14,7 +14,7 @@ authorName = 'Troy Melhase'
authorEmail = bugsEmailAddress = 'troy@gci.net'
version = '0.1'
shortDescription = 'The PyKDE Sampler'
-licenseType = KAboutData.License_GPL_V2
+licenseType = TDEAboutData.License_GPL_V2
copyrightStatement = '(c) 2006, %s' % (authorName, )
homePageAddress = 'http://www.riverbankcomputing.co.uk/pytde/'
aboutText = ("The application sampler for PyKDE.")
@@ -22,10 +22,10 @@ contributors = [] # module-level global for keeping the strings around; intentio
def about():
""" creates KAboutData instance for the app
"""
- about = KAboutData(
+ about = TDEAboutData(
appName,
progName,
version,
@@ -22,10 +22,10 @@ contributors = [] # module-level global for keeping the strings around; intentio
def about():
- """ creates KAboutData instance for the app
+ """ creates TDEAboutData instance for the app
"""